The maximum age in LAR is set as 100. If the data contains
birth which makes attained age (=current - birth)
exceed 100, the result has no useful value.
data should include information which includes gender, year of birth,
year of exposure, sites where exposed, exposure rate, distribution of dose and
dose parameters of exosed radiation. The name of each variables must be
sex, birth, exposure, site, exposure_rate,
dosedist, dose1, dose2, dose3.
For some variables, there is a fixed format. sex can have the component 'male' or 'female'.
site can have the component 'stomach', 'colon', 'liver', 'lung', 'breast', 'ovary', 'uterus', 'prostate', 'bladder', 'brain/cns',
'thyroid', 'remainder', 'oral', 'oesophagus', 'rectum', 'gallbladder', 'pancreas', 'kidney', 'leukemia'.
exposure_rate can have the component 'acute' or 'chronic'.
dosedist can have the component 'fixedvalue', 'lognormal', 'normal', 'triangular', 'logtriangular', 'uniform', 'loguniform'.
dose1, dose2, dose3 are parameters of dose distribution. The parameters for each distribution are that:
- fixedvalue
dose value (dose1)
- lognormal
median (dose1), geometric standard deviation (dose2)
- normal
mean (dose1), standard deviation (dose2)
- triangular or logtriangular
minimum (dose1), mode (dose2), maximum (dose3)
- uniform or loguniform
minimum (dose1), maximum (dose2)
weight