Learn R Programming

LARisk (version 1.0.0)

print.LAR: Print estimated Lifetime Attributable Risk for one person

Description

print.LAR is the basic function for printing class "LAR".

Usage

# S3 method for LAR
print(x, digits = 4, ...)

# S3 method for LAR_batch print(x, digits = 4, max.id = 50, ...)

# S3 method for LAR_group print(x, digits = 4, max.id = 50, ...)

Arguments

x

'LAR', 'LAR_batch' or 'LAR_group' object.

digits

the number of decimal points to print.

...

further arguments to be passed from or to other methods.

max.id

the number of maximum of printing LAR results.