print.LAR is the basic function for printing class "LAR".
# S3 method for LAR
print(x, digits = 4, ...)# S3 method for LAR_batch
print(x, digits = 4, max.id = 50, ...)
# S3 method for LAR_group
print(x, digits = 4, max.id = 50, ...)
'LAR', 'LAR_batch' or 'LAR_group' object.
the number of decimal points to print.
further arguments to be passed from or to other methods.
the number of maximum of printing LAR results.